@@ -590,9 +590,9 @@ void showReadMe()
   char buf[4096*4];	//buffer to hold data
   int buf_len = 0;
   
-  if(!(README = fopen("/usr/share/doc/mino/README", "r"))) 
+  if(!(README = fopen("/usr/share/doc/gnudos/mino/README", "r"))) 
   {
-   if(!(README = fopen("/usr/local/share/doc/mino/README", "r"))) 
+   if(!(README = fopen("/usr/local/share/doc/gnudos/mino/README", "r"))) 
    {
     msgBox("Failed to open README file!.", OK, ERROR);
     //scanDir(cwd);
